/** \addtogroup config 
 *  @{ */
 //* \file        TueObjFusn_ConfigVehicle.h
 //*
 //* 
 //*
 //* <br>=====================================================<br>
 //* <b>Copyright 2016 by Tuerme.</b>
 //*
 //*  All rights reserved. Property of Tuerme.<br>
 //*  Restricted rights to use, duplicate or disclose of this code<br>
 //*  are granted through contract.
 //* <br>=====================================================<br>
 //*/


#ifndef TUEOBJFUSN_CONFIGVEHICLE_H
#define TUEOBJFUSN_CONFIGVEHICLE_H

#ifdef	__cplusplus
extern "C" {
#endif

/*==================[inclusions]============================================*/
/*==================[macros]================================================*/
/**
 * Define maximum number of sensor input object lists.
 * strongly affects memory footprint of certain fusion modes 
 */
#define TUE_PRV_FUSION_MAX_INPUTS         (2u)

/* From Driving function project: */
#define OPS_CLASS_PRIO_QUOTA_CUSTOM \
    (0u)  // Quota for customer
          // requirement object : 0/20
#define OPS_CLASS_PRIO_QUOTA_DYNAMIC_POE_AND_CLOSE \
    (19u)  // Quota for dynamic object
           // with high POE and close to ego trajectory : 10/20
#define OPS_CLASS_PRIO_QUOTA_STATIC_POE_AND_CLOSE \
    (13u)  // Quota for static object
           // with high POE and close to ego trajectory : 7/20
#define OPS_CLASS_PRIO_QUOTA_DYNAMIC_POE_OR_CLOSE \
    (3u)  // Quota for dynamic object
          // with high POE or close to ego trajectory : 0/20
#define OPS_CLASS_PRIO_QUOTA_ONCOMING_POE_OR_CLOSE \
    (5u)  // Quota for oncoming object
          // with high POE or close to ego trajectoryy : 3/20
#define OPS_CLASS_PRIO_QUOTA_STATIC_POE_OR_CLOSE \
    (0u)  // Quota for static object
          // with high POE or close to ego trajectory : 0/20
#define OPS_CLASS_PRIO_QUOTA_OTHER (0u)  // Quota for other object : 0/20

#if PROJECT_ZT_OBJECT_OPTIMIZATION_FOR_RAM
/**
 * maximum number of objects from any of the radar sensors
 */
#if ( defined(EP30_ON) && EP30_ON == 1 )
#define TUE_PRV_FUSION_MAX_OBJECTS_RADAR   (40u)//(20u)//change to 40u for EP30+410 Radar requirement
#else
// 20u
#define TUE_PRV_FUSION_MAX_OBJECTS_RADAR   (OPS_CLASS_PRIO_QUOTA_CUSTOM+OPS_CLASS_PRIO_QUOTA_DYNAMIC_POE_AND_CLOSE+OPS_CLASS_PRIO_QUOTA_STATIC_POE_AND_CLOSE+OPS_CLASS_PRIO_QUOTA_DYNAMIC_POE_OR_CLOSE+OPS_CLASS_PRIO_QUOTA_ONCOMING_POE_OR_CLOSE+OPS_CLASS_PRIO_QUOTA_STATIC_POE_OR_CLOSE+OPS_CLASS_PRIO_QUOTA_OTHER)//(20u)//change to from define value to the total number of OPS output

#endif
#else
 /**
  * maximum number of objects from any of the radar sensors
  */
#define TUE_PRV_FUSION_MAX_OBJECTS_RADAR   (100u)//change to 100 for testing only by guotao 20190509
#endif

//the maximum number of objects from camera pedestrian structure
#define TUE_PRV_CAMERA_PEDESTRIAN_MAX_OBJECTS (7u)

//the maximum number of objects from camera other car structure
#define TUE_PRV_CAMERA_OTHER_CAR_MAX_OBJECTS (16u)

//the maximum number of used other car number for camera objects
#define TUE_PRV_CAMERA_USED_OTHER_CAR_MAX_OBJECTS (5u)

//Ticket:http://119.3.139.124:10101/tickets/DFA-ZT19.git/31 changed by changchang 20200603 start
//the maximum number of used pedestrian number for pedestrian objects
#define TUE_PRV_CAMERA_USED_PEDESTRIAN_MAX_OBJECTS (7u)
//Ticket:http://119.3.139.124:10101/tickets/DFA-ZT19.git/31 changed by changchang 20200603 end

#if PROJECT_ZT_OBJECT_OPTIMIZATION_FOR_RAM
/**
 * maximum number of objects from any of the vision sensors
 */
#if ( defined(EP30_ON) && EP30_ON == 1 )
#define TUE_PRV_FUSION_MAX_OBJECTS_VISION  (24u) /* \todo: set to 14! */ //change to 14 from 24 by guotao 20190508
#else
#define TUE_PRV_FUSION_MAX_OBJECTS_VISION  (24u) /* \todo: set to 14! */ //change to 14 from 24 by guotao 20190508
#endif
#else
#define TUE_PRV_FUSION_MAX_OBJECTS_VISION  (24u) /* \todo: set to 21! */ //change to 24 from 24 by guotao 20190508
#endif
/**
 * number of buffer items for ego motion storage.
 * Ego motion data is buffered at the fusion cycle rate (usually 100Hz).
 * The buffer must be large enough to store ego motion for at least the
 * duration of maximum expected input measurement latency
 */
#define TUEOBJFUSN_EGOMOTIONHISTORY_SIZE (30u) //TODO what is a good value

/**
  * High ego acceleration and deceleration result in an increased uncertainity of the 
  * longitudinal acceleration measured by the sensor.
  * To reflect this uncertainity, the acceleration variance calculated by the sensor model shall be 
  * corrected using the increased uncertainity caused by the acceleration and deceleration of the ego vehicle.
  * This is done using a linear model with offset and slope 
  */
#define TUEOBJFUSN_EGOMOTION_VARIANCE_ACC_SLOPE    (0.65f)

/** 
 * High yaw rate of the ego vehicle causes a higher uncertainity in 
 * the lateral velocity. This is especially true for statioary radar targets 
 */
#define TUEOBJFUSN_EGOMOTION_VARIANCE_YAW_SLOPE    (0.0f)


/**
 * distance from front bumper to rear axle of the vehicle 
 */
//Ticket:http://119.3.139.124:10101/tickets/DFA-ZT19.git/5 changed by guotao 20200422 start
//#ifdef FUSION_SIMULATION_VS_CONF
//#define TUE_PRV_VEHICLE_DISTANCE_REAR_AXLE_TO_FRONT_BUMBER  (0.0f)  
//#else
//#define TUE_PRV_VEHICLE_DISTANCE_REAR_AXLE_TO_FRONT_BUMBER  (3.455f) 
//#endif
#define TUE_PRV_VEHICLE_DISTANCE_REAR_AXLE_TO_FRONT_BUMBER  (0.0f)  
//Ticket:http://119.3.139.124:10101/tickets/DFA-ZT19.git/5 changed by guotao 20200422 end
/** 
 * Offset of camera to front bumber, i.e. front bumber is xx m in front of MVS 
 */
#define TUE_PRV_VEHICLE_CAM_TO_FRONT_BUMBER  (1.59723f)

/**
 * Lateral offset of MVS sensor to x-axis of front bumber coordinate system 
 * Identical to offset to rear axle coordinate system. Offset to driver side 
 */
#define TUE_PRV_VEHICLE_LATERAL_OFFSET_CAM   (-0.017f)  

/** 
 * Longitudinal value of origin of camera coordinate system in rear axle coordinate system 
 */
#define TUE_PRV_VEHICLE_DISTANCE_REAR_AXLE_TO_CAMERA         (TUE_PRV_VEHICLE_DISTANCE_REAR_AXLE_TO_FRONT_BUMBER - TUE_PRV_VEHICLE_CAM_TO_FRONT_BUMBER) /*1 .730 is from front bumper to camera -> distance is approx. 2m in front of rear axle */

/**
 * Buffer Size used in error management for the ring buffer implementation
 */
#if PROJECT_ZT_RAM_REDUCTION_SWITCH
#define TUE_PRV_ERROR_MANAGEMENT_BUFFER_SIZE    (5u)
#else
#define TUE_PRV_ERROR_MANAGEMENT_BUFFER_SIZE    (30u)

#endif
/*
 * A sensor timeout is assumed as soon as the last sensor update is older than specified 
 */
#define TUE_PRV_VEHICLE_SENSOR_TIMEOUT          (0.300f)

#ifdef ALGO_SAFETY_DISTANCE_FOR_TEST_ONLY
#define ALGO_EXTEND_SAFETY_DISTANCEX_FOR_TEST (15.0f)
#endif

/*==================[type definitions]======================================*/
/*==================[functions]============================================*/
/*==================[external function declarations]========================*/
/*==================[external constants]====================================*/
/*==================[external data]=========================================*/

#ifdef __cplusplus
}
#endif

#endif /* TUEOBJFUSN_CONFIGVEHICLE_H */
/**@}==================[end of file]===========================================*/
